@@ -120,7 +120,7 @@ class Wsdl(WsdlBase):
             lambda group: group(_("Video"),
                                 normal=('os_install_x11_video_drv',
                                         'os_install_x11_composite',
-                                        'os_install_x11_resolution',
+                                        'os_install_x11_resolution_preferred',
                                         'os_install_fb_resolution',
                                         'os_install_grub_terminal')),
             lambda group: group(_("Update"),
@@ -288,16 +288,17 @@ class Wsdl(WsdlBase):
             'setvars': {'cl_action!': 'merge', 'cl_merge_pkg!': [None],
                         'cl_merge_set!': "on", 'cl_setup': 'video'},
             'groups': [
-                lambda group: group(_("Video"),
-                                    normal=('os_install_x11_video_drv',
-                                            'os_install_x11_resolution',
-                                            'os_install_x11_composite',
-                                            'os_install_fb_resolution'),
-                                    expert=(
-                                        'cl_templates_locate',
-                                        'cl_dispatch_conf',
-                                        'cl_verbose_set'),
-                                    next_label=_("Save"))]},
+                lambda group: group(
+                    _("Video"),
+                    normal=('os_install_x11_video_drv',
+                            'os_install_x11_resolution_preferred',
+                            'os_install_x11_composite',
+                            'os_install_fb_resolution'),
+                    expert=(
+                        'cl_templates_locate',
+                        'cl_dispatch_conf',
+                        'cl_verbose_set'),
+                    next_label=_("Save"))]},
         {
             # настройка звука
             'method_name': "setup_audio",
